@@ -21,13 +21,8 @@
 #ifndef MixDevice_h
 #define MixDevice_h
 
-#if defined(HAVE_STD_SHARED_PTR)
 #include <memory>
 using std::shared_ptr;
-#elif defined(HAVE_STD_TR1_SHARED_PTR)
-#include <tr1/memory>
-using std::tr1::shared_ptr;
-#endif
 
 //KMix
 #include "core/MediaController.h"
